/**
    (C) Copyright 2012 Dominik Wagenfuehr

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DECLINESTRATEGY_HH
#define DECLINESTRATEGY_HH

#include "IStrategy.hh"

class DeclineStrategy : public IStrategy
{
  public:
    /// Akzeptiert oder lehnt ein Angebot ab.
    /**
     * Das Angebot wird immer abgelehnt.
     * Der angebotene Wert muss zwischen 0 und 1000 liegen.
     * @param value Der angebotene Wert.
     * @return false
     */
    bool acceptOffer( const int value );

    /// Erstellt eine Kopie des Elements.
    /**
     * Wenn man abgeleitete Klassen von einer Basis-Klasse hat
     * und nur mit einem Pointer auf die Basis-Klasse arbeitet,
     * lassen sich Objekte nicht so einfach per Zuweisung kopieren
     * da man ja die exakte Klassen benötigt. In dem Fall arbeitet
     * man mit einer virtuellen copy-Methode, welche in jeder
     * abgeleiteten Klasse implementiert werden muss.
     * @return Pointer auf die Kopie des Objekt.
     */
    virtual IStrategy* copy() const;
};

#endif // DECLINESTRATEGY_HH
